# pyspeckle

A basic collection of routines to track and analyze speckle

Currently incomplete and untested

## Usage

For examples, see the (non-existent) doc directory

## Installation

Use `pip`

    pip install pyspeckle

Alternatively you can install from github

    git clone https://github.com/scottprahl/pyspeckle.git

and add the `pyspeckle` directory to your PYTHONPATH


### Dependencies

Required Python modules: numpy, matplotlib, scipy


### License

pyspeckle is licensed under the terms of the MIT license.